#!/bin/sh
#

DIS=$1
if test -z "${DIS}"; then
	DIS=":0.0"
fi


# Use default wm
if test -z "${WM}"; then
	WM="twm"
fi
if test -z "${XMODMAP}"; then
	XMODMAP="xmodmap"
fi
if test -z "${XAUTH}"; then
	XAUTH="xauth"
fi

if test x"$XAUTHORITY" = x; then
	XAUTHORITY=$HOME/.Xauthority
	export XAUTHORITY
fi

removelist=


# set up default Xauth info for this machine
case `uname` in
Linux*) 
	if [ -z "`hostname --version 2>&1 | grep GNU`" ]; then
		hostname=`hostname -f`
	else
		hostname=`hostname`
	fi
	;;
*)
	hostname=`hostname`
	;;
esac

authdisplay=${DIS}
if test -x "/usr/bin/mcookie"; then
	mcookie=`/usr/bin/mcookie`
else
	mcookie=`dd if=/dev/urandom bs=16 count=1 2>/dev/null | hexdump -e \\"%08x\\"`
fi
dummy=0

# create a file with auth information for the server: ':0' is a dummy.
xserverauthfile=$HOME/.serverauth.$$
${XAUTH} -q -f $xserverauthfile << EOF
add :$dummy . $mcookie
EOF

for displayname in $authdisplay $hostname$authdisplay; do
	authcookie=`xauth list "$displayname" \
		| sed -n "s/.*$displayname[[:space:]*].*[[:space:]*]//p"` 2>/dev/null;
	if test "z${authcookie}" = "z"; then
		${XAUTH} -q << EOF
add $displayname . $mcookie
EOF
		removelist="$displayname $removelist"
	else
		dummy=$((dummy+1));
		${XAUTH} -q -f $xserverauthfile << EOF
add :$dummy . $authcookie
EOF
	fi
done


LOGFILE=`echo ".xggi${DIS}.log" | sed -e "s/:/./g"`


# We start the clients _first_ with a short delay,
# then the Server. This tricky thing lets the
# Server attached onto the controlling tty and
# therefore needs no root permission.

( # FIXME: export is bash specific!
 DISPLAY=${DIS}; export DISPLAY; \
 sleep 3; ${WM} & sleep 1 ;\
 ${XMODMAP} /etc/X11/keymaps/xggimap.base ; \
 ${XMODMAP} /etc/X11/keymaps/xggimap.de_de \
) &

if test -z "${DEBUG}"; then
	exec XGGI $@ >$HOME/${LOGFILE} 2>&1
else
	${DEBUG} `which XGGI`
fi

if test x"$removelist" != x; then
	${XAUTH} remove $removelist
fi
if test x"$xserverauthfile" != x; then
	rm -f $xserverauthfile
fi
